Welcome to tellcore-py's documentation!
=======================================

tellcore-py is a Python wrapper for `Telldus' <http://www.telldus.com/>`_ home
automation library `Telldus Core <http://developer.telldus.se/doxygen/>`_.

Contents:

.. toctree::
   :maxdepth: 2

   telldus
   constants
   library
   tool_example
   event_example
   news

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
